@@ -6,9 +6,9 @@
 # change 'tests => 1' to 'tests => last_test_to_print';
 
 use Test::More;
-BEGIN { plan tests => 78 + 2*8};
+BEGIN { plan tests => 266};
 use File::Random;
-ok(1); # If we made it this far, we're ok.
+ok 1, "Stupid Load test"; # If we made it this far, we're ok.
 
 #########################
 
